import { AlertService, Button, Grid } from '@zeedhi/common';
import {
  Http, IDictionary, IEventParam, Router,
} from '@zeedhi/core';

export default class DashboardController {
  public preencherSolicitacoesGrid({ component }: { component: Grid }) {
    Http.get('/SolicitacaoServ/Equipamento/CategoriaManut/Funcionario')
      .then((response) => {
        const data = response.data.dataset.SolicitacaoServ;
        this.preencherGrid(component, data)
          .catch((err) => {
            AlertService.show({
              name: 'alert-error',
              color: 'error',
              text: err,
              top: true,
              left: false,
              timeout: 1500,
            });
          });
      })
      .catch((err) => {
        AlertService.show({
          name: 'alert-error',
          color: 'error',
          text: err,
          top: true,
          left: false,
          timeout: 1500,
        });
      });
  }

  public redirecionarCriarOS({ row }: IEventParam<Button>) {
    Router.replace(`/solicitacao?${row.NRSOLICITACAOSERV}`);
  }

  public imprimirOrdem({ row }: IEventParam<Button>) {
    const newWindow = window.open();
    const ordemHTML = `
    <div>
      <center>
        <h3> Ordem de Serviço </h3>
      </center>
      <div style="display: flex;">
        <div style="margin-right: 3%">
            <h5>
            Nr. da Ordem
            </h5>
          <p> ${row.NRORDEMSERV} </p>
        </div>
        <div style="margin-right: 3%">
          <h5> 
            Categoria 
          </h5>
          <p> ${row.NMCATEGORIAMANUT} </p>
        </div>
        <div style="margin-right: 3%">
          <h5>
            Tipo
          </h5>
          <p> ${row.NMTIPOMANUTENCAO} </p>
        </div>
        <div style="margin-right: 3%">
          <h5>
            Data
          </h5>
          <p> ${row.DTORDEMSERV} </p>
        </div>
      </div>
      
      <div>
        <h5>
          Equipamento
        </h5>
        <p> ${row.NMEQUIPAMENTO} </p>
      </div>
      
      <div>
        <h5>
          Responsáveis
        </h5>
        <p> ${row.NMFUNCIONARIO} </p>
      </div>
      
      <div>
        <h5>
          Descrição
        </h5>
        <p>Descrição</p>
      </div>
      
    </div>
  `;
    newWindow?.document.write(ordemHTML);
    newWindow?.print();
  }

  public preencherOrdensGrid({ component }: { component: Grid }) {
    Http.get('/OrdemServ/Equipamento/CategoriaManut/PrioridadeManut/ResponsaveisOrdemServ/Funcionario')
      .then((response) => {
        const data = response.data.dataset.OrdemServ;
        const auxData: IDictionary = {};
        data.forEach((ordemServ: IDictionary) => {
          const key = ordemServ.NRORDEMSERV.toString();
          if (key in auxData) {
            auxData[key].NMFUNCIONARIO += `, ${ordemServ.NMFUNCIONARIO}`;
          } else {
            auxData[key] = ordemServ;
          }
        });
        const formatedData: Array<IDictionary> = [];
        Object.keys(auxData).forEach((currentKey) => {
          formatedData.push(auxData[currentKey]);
        });
        this.preencherGrid(component, formatedData)
          .catch((err) => {
            AlertService.show({
              name: 'alert-error',
              color: 'error',
              text: err,
              top: true,
              left: false,
              timeout: 1500,
            });
          });
      })
      .catch((err) => {
        AlertService.show({
          name: 'alert-error',
          color: 'error',
          text: err,
          top: true,
          left: false,
          timeout: 1500,
        });
      });
  }

  public async preencherGrid(component: Grid, data: any) {
    component.datasource.updateData(data);
    return true;
  }
}
